# -*- coding: utf-8 -*-

from setuptools import setup

long_description = '''\
This distribution is a stub
that doesn’t install any Python packages,
but does list ``ephem`` as an install requirement
in case any old projects depend on this ``pyephem`` package name.
New projects are encouraged to directly require the main package,
which can be found at:

`https://pypi.org/project/ephem/ <https://pypi.org/project/ephem/>`_

This package’s version 9.99 is merely a placeholder value.
This package does not pin any particular PyEphem version,
but simply installs the latest version of the library.
Switch your project to depending on ``ephem`` directly
if you want to be able to pin a specific version.
'''

setup(
    name = 'pyephem',
    version = '9.99',
    description = 'Empty package that depends on "ephem"',
    long_description = long_description,
    long_description_content_type = 'text/x-rst',
    license = 'MIT',
    author = 'Brandon Rhodes',
    author_email = 'brandon@rhodesmill.org',
    url = 'http://rhodesmill.org/pyephem/',
    classifiers = [
        'Development Status :: 6 - Mature',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Astronomy',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    install_requires=['ephem'],
)



#!/usr/bin/env python

from urllib2 import urlopen, HTTPError
import re

# Look up each city in "cities.in" on the http://www.fallingrain.com/
# web site, and append their geographic data into "cities.out".

cin = open('cities.in', 'r')
cout = open('cities.out', 'a')

def transchar(c):
    if c == ' ':
        return '32'
    elif c == '-':
        return '45'
    elif c == '.':
        return '46'
    return c

def get_page(name, n):
    url = 'http://www.fallingrain.com/world/a/' + '/'.join(
        [ transchar(c) for c in name[:n] ]
        )
    try:
        return urlopen(url).read()
    except HTTPError:
        return None

def rename(name):
    bettername = {
        'Hong Kong historical': 'Hong Kong',
        'Mexico': 'Mexico City',
        'Sankt-Peterburg': 'St. Petersburg',
        }.get(name, None)
    return bettername or name

class Entry(object):
    pass

def get_entries(content):
    entries = []
    for line in content.split('\n'):
        if line.startswith('<tr><td>'):
            fields = re.split(r'<[^>]*>', line)
            e = Entry()
            e.name = fields[3]
            e.type = fields[5]
            e.lat = fields[8]
            e.lon = fields[9]
            e.elev = fields[10]
            e.pop = int(fields[11])

            entries.append(e)

    return entries

for line in cin:
    line = line.strip()
    if not line or line.startswith('#'):
        continue

    name = line
    i = 4                      # first guess for how deep the URL goes
    content = get_page(name, i)
    if not content:             # we went too deep
        while not content:
            i -= 1
            content = get_page(name, i)
    else:
        while content and i <= len(name):
            old_content = content
            i += 1
            content = get_page(name, i)
        content = old_content

    entries = get_entries(content)
    entries = [ e for e in entries if e.type == 'city' ]
    entries = [ e for e in entries if e.name == name ]

    if entries:
        esort = [ (e.pop, e) for e in entries ]
        esort.sort()
        e = esort[-1][1]
        s = "    '%s': ('%s', '%s', %f)," % (rename(e.name), e.lat, e.long,
                                             float(e.elev) * 0.3048)
        print s
        print >>cout, s
    else:
        print '-------- cannot find:', name
        print >>cout, '-------- cannot find:', name
